==> checkstyle-8.42-tests.jar: com/puppycrawl/tools/checkstyle/checks/javadoc/nonemptyatclausedescription/InputNonEmptyAtclauseDescription.java <==
package com.puppycrawl.tools.checkstyle.checks.javadoc.nonemptyatclausedescription;
class InputNonEmptyAtclauseDescription
{
        /**
         * Some javadoc.
         * @param a Some javadoc.
         * @param b Some javadoc.
         */
        public InputNonEmptyAtclauseDescription(String a, int b)
        {

        }

        /**
         * Some javadoc.
         * @param a Some javadoc.
         * @deprecated Some javadoc.
         */
        public InputNonEmptyAtclauseDescription(String a)
        {

        }

        /**
         * Some javadoc.
         * @param a
         * @param b
         * @param c
         */
        public InputNonEmptyAtclauseDescription(String a, int b, double c)
        {

        }

        /**
         *
         * @param a
         * @param e
         * @deprecated
         */
        public InputNonEmptyAtclauseDescription(String a, boolean e)
        {

        }

        /**
         * Some javadoc
         * @param a Some javadoc
         * @param b Some javadoc
         * @param c Some javadoc
         * @return Some javadoc
         * @throws Exception Some javadoc
         * @deprecated Some javadoc
         */
        public int foo1(String a, int b, double c) throws Exception
        {
                return 1;
        }

        /**
         *
         * @param a Some javadoc
         * @param b Some javadoc
         * @param c Some javadoc
         * @return Some javadoc
         * @throws Exception Some javadoc
         */
        public int foo2(String a, int b, double c) throws Exception
        {
                return 1;
        }

        /**
         *
         * @param a
         * @param b
         * @param c
         * @deprecated
         * @throws Exception
         * @deprecated
         */
        public int foo3(String a, int b, double c) throws Exception
        {
                return 1;
        }

        /**
         *
         * @param a
         * @param b
         * @param c
         * @deprecated
         * @throws Exception
         */
        public int foo4(String a, int b, double c) throws Exception
        {
                return 1;
        }

        /**
         * Some javadoc
         * @param a Some javadoc
         * @param b Some javadoc
         * @param c Some javadoc
         * @return Some javadoc
         * @exception Exception Some javadoc
         * @deprecated Some javadoc
         */
        public int foo5(String a, int b, double c) throws Exception
        {
                return 1;
        }

        /**
         *
         * @param a Some javadoc
         * @param b Some javadoc
         * @param c Some javadoc
         * @return Some javadoc
         * @exception Exception
         */
        public int foo6(String a, int b, double c) throws Exception
        {
                return 1;
        }

        /**
         * @param a xxx
         * @return
         */     // ^ violation
        int foo(int a) {
                return a;
        }

        /**
         * @return {@code 1}
         */     // ^ ok
        int bar() {
                return 1;
        }
}

==> checkstyle-9.2-tests.jar: com/puppycrawl/tools/checkstyle/checks/javadoc/nonemptyatclausedescription/InputNonEmptyAtclauseDescription.java <==
/*
NonEmptyAtclauseDescription
violateExecutionOnNonTightHtml = (default)false
javadocTokens = (default)PARAM_LITERAL, RETURN_LITERAL, THROWS_LITERAL, \
                EXCEPTION_LITERAL, DEPRECATED_LITERAL


*/

package com.puppycrawl.tools.checkstyle.checks.javadoc.nonemptyatclausedescription;

class InputNonEmptyAtclauseDescription
{
        /**
         * Some javadoc.
         * @param a Some javadoc.
         * @param b Some javadoc.
         */
        public InputNonEmptyAtclauseDescription(String a, int b)
        {

        }

        /**
         * Some javadoc.
         * @param a Some javadoc. // ok
         * @deprecated Some javadoc.
         */
        public InputNonEmptyAtclauseDescription(String a)
        {

        }

        /**
         * Some javadoc.
         * @param a
         * @param b
         * @param c
         */
        public InputNonEmptyAtclauseDescription(String a, int b, double c)
        {

        }

        /**
         *
         * @param a
         * @param e
         * @deprecated
         */
        public InputNonEmptyAtclauseDescription(String a, boolean e)
        {

        }

        /**
         * Some javadoc
         * @param a Some javadoc
         * @param b Some javadoc
         * @param c Some javadoc
         * @return Some javadoc
         * @throws Exception Some javadoc
         * @deprecated Some javadoc
         */
        public int foo1(String a, int b, double c) throws Exception
        {
                return 1;
        }

        /**
         *
         * @param a Some javadoc
         * @param b Some javadoc
         * @param c Some javadoc
         * @return Some javadoc
         * @throws Exception Some javadoc
         */
        public int foo2(String a, int b, double c) throws Exception
        {
                return 1;
        }

        /**
         *
         * @param a
         * @param b
         * @param c
         * @deprecated
         * @throws Exception
         * @deprecated
         */ // violation above
        public int foo3(String a, int b, double c) throws Exception
        {
                return 1;
        }

        /**
         *
         * @param a
         * @param b
         * @param c
         * @deprecated
         * @throws Exception
         */
        public int foo4(String a, int b, double c) throws Exception
        {
                return 1;
        }

        /**
         * Some javadoc
         * @param a Some javadoc
         * @param b Some javadoc
         * @param c Some javadoc
         * @return Some javadoc
         * @exception Exception Some javadoc
         * @deprecated Some javadoc
         */
        public int foo5(String a, int b, double c) throws Exception
        {
                return 1;
        }

        /**
         *
         * @param a Some javadoc
         * @param b Some javadoc
         * @param c Some javadoc
         * @return Some javadoc
         * @exception Exception
         */
        public int foo6(String a, int b, double c) throws Exception
        {
                return 1;
        }

        /**
         * @param a xxx
         * @return
         */     // ^ violation
        int foo(int a) {
                return a;
        }

        /**
         * @return {@code 1}
         */     // ^ ok
        int bar() {
                return 1;
        }
}
